Skip to contents

Visualise sequential distributions using a range of plotting styles. Sequential distribution data can be input as either simulations or values corresponding to percentiles over time. Plots are added to existing graphic devices using the fan function. Users can choose from four different styles, including fan chart type plots, where a set of coloured polygons, with shadings corresponding to the percentile values, are layered to represent different uncertainty levels.

Details

License: GPL-2

References

Abel, G. J. (2015). fanplot: An R Package for visualising sequential distributions. The R Journal, 7(2), 15–23.

Author

Guy J. Abel